package com.ruoyi.voluntary.mapper;

import java.util.List;
import com.ruoyi.voluntary.domain.BusiCardsOpen;
import com.ruoyi.voluntary.domain.BusiCardsOpenDetail;

/**
 * 开卡Mapper接口
 * 
 * @author voluntary
 * @date 2022-12-03
 */
public interface BusiCardsOpenMapper 
{
    /**
     * 查询开卡
     * 
     * @param id 开卡主键
     * @return 开卡
     */
    public BusiCardsOpen selectBusiCardsOpenById(Long id);

    /**
     * 查询开卡列表
     * 
     * @param busiCardsOpen 开卡
     * @return 开卡集合
     */
    public List<BusiCardsOpen> selectBusiCardsOpenList(BusiCardsOpen busiCardsOpen);

    /**
     * 新增开卡
     * 
     * @param busiCardsOpen 开卡
     * @return 结果
     */
    public int insertBusiCardsOpen(BusiCardsOpen busiCardsOpen);

    /**
     * 修改开卡
     * 
     * @param busiCardsOpen 开卡
     * @return 结果
     */
    public int updateBusiCardsOpen(BusiCardsOpen busiCardsOpen);

    /**
     * 删除开卡
     * 
     * @param id 开卡主键
     * @return 结果
     */
    public int deleteBusiCardsOpenById(Long id);

    /**
     * 批量删除开卡
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBusiCardsOpenByIds(Long[] ids);

    /**
     * 批量删除开卡详情
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBusiCardsOpenDetailByOpenIds(Long[] ids);
    
    /**
     * 批量新增开卡详情
     * 
     * @param busiCardsOpenDetailList 开卡详情列表
     * @return 结果
     */
    public int batchBusiCardsOpenDetail(List<BusiCardsOpenDetail> busiCardsOpenDetailList);
    

    /**
     * 通过开卡主键删除开卡详情信息
     * 
     * @param id 开卡ID
     * @return 结果
     */
    public int deleteBusiCardsOpenDetailByOpenId(Long id);
}
